@@ -7,14 +7,13 @@ import (
 	"os"
 	"runtime"
 
-	"github.com/openshift-knative/knative-openshift-ingress/pkg/apis"
-	"github.com/openshift-knative/knative-openshift-ingress/pkg/controller"
-	"github.com/openshift-knative/knative-openshift-ingress/pkg/util"
+	"github.com/openshift-knative/serverless-operator/serving/ingress/pkg/apis"
+	"github.com/openshift-knative/serverless-operator/serving/ingress/pkg/controller"
+	"github.com/openshift-knative/serverless-operator/serving/ingress/pkg/util"
 
 	"github.com/operator-framework/operator-sdk/pkg/k8sutil"
 	"github.com/operator-framework/operator-sdk/pkg/leader"
 	"github.com/operator-framework/operator-sdk/pkg/log/zap"
-	"github.com/operator-framework/operator-sdk/pkg/metrics"
 	"github.com/operator-framework/operator-sdk/pkg/restmapper"
 	sdkVersion "github.com/operator-framework/operator-sdk/version"
 	"github.com/spf13/pflag"
@@ -108,7 +107,7 @@ func main() {
 
 	// Listen for the CRDs we depend on the be available.
 	log.Info("Waiting for necessary CRDs to be applied.")
-	if err := util.WaitForCRDs(mgr, stopCh, &networkingv1alpha1.ClusterIngress{}, &networkingv1alpha1.Ingress{}); err != nil {
+	if err := util.WaitForCRDs(mgr, stopCh, &networkingv1alpha1.Ingress{}); err != nil {
 		log.Error(err, "")
 		os.Exit(1)
 	}
@@ -119,12 +118,6 @@ func main() {
 		os.Exit(1)
 	}
 
-	// Create Service object to expose the metrics port.
-	_, err = metrics.ExposeMetricsPort(ctx, metricsPort)
-	if err != nil {
-		log.Info(err.Error())
-	}
-
 	log.Info("Starting the Cmd.")
 
 	// Start the Cmd
